Learn R Programming

lingglosses (version 0.0.11)

add_gloss: Gloss an example

Description

Adds glosses to the glosses list and adds small capitals to glosses. Escapes strings that begins and ends with curly brackets.

Usage

add_gloss(glosses)

Value

vector of small capitalized glosses (if string is in the upper case) and not glosses (if string is not in the upper case)

Arguments

glosses

character vector with glosses in upper case.

Author

George Moroz <agricolamz@gmail.com>

Examples

Run this code
add_gloss(c("ABS", "ERG"))

Run the code above in your browser using DataLab