Converts example to a data.frame and adds it to the database of Interlinear-Glossed examples.
convert_to_df(
transliteration,
glosses,
free_translation = "",
comment = "",
annotation = NULL,
drop_transliteration = FALSE,
write_to_db = TRUE,
counter = getOption("lingglosses.example_counter")
)dataframe with
character vector of the length one for the transliteration line.
character vector of the length one for the glosses line.
character vector of the length one for the free translation line.
character vector of the length one for the comment line (under the free translation line).
character vector of the length one for the annotation line (above translation).
logical variable that denotes, whether user wants to have an example without transliteration.
logical variable that denotes, whether example should be added to the example database.
double, value that denotes example id. By default gathered automatically through hidden variables in the Rmd document.
George Moroz <agricolamz@gmail.com>