powered by
Adds glosses to the glosses list and adds small capitals to glosses. Escapes strings that begins and ends with curly brackets.
add_gloss(glosses)
vector of small capitalized glosses (if string is in the upper case) and not glosses (if string is not in the upper case)
character vector with glosses in upper case.
George Moroz <agricolamz@gmail.com>
add_gloss(c("ABS", "ERG"))
Run the code above in your browser using DataLab